@@ -1,2 +1,2 @@
 from flask.cli import main
-main(as_module=True)
+main()
