@@ -1,7 +1,7 @@
 from flask import g
 from frasco.ext import *
 from frasco.i18n import set_translation_callbacks
-from flask_babel import (Babel, gettext, ngettext, lazy_gettext, format_datetime, format_date,
+from flask_babel import (Babel, gettext, pgettext, ngettext, npgettext, lazy_gettext, lazy_pgettext, format_datetime, format_date,
                          format_time, format_currency as babel_format_currency)
 from babel import Locale
 
@@ -66,9 +66,9 @@ class FrascoBabel(Extension):
 
         app.cli.add_command(babel_cli)
 
-        set_translation_callbacks(translate=gettext,
-                                  ntranslate=ngettext,
-                                  lazy_translate=lazy_gettext,
+        set_translation_callbacks(translate=translate,
+                                  ntranslate=ntranslate,
+                                  lazy_translate=lazy_translate,
                                   format_datetime=format_datetime,
                                   format_date=format_date,
                                   format_time=format_time)
@@ -107,6 +107,24 @@ class FrascoBabel(Extension):
             timeformat=format_time, currencyformat=format_currency)
 
 
+def translate(string, context=None):
+    if context:
+        return pgettext(context, string)
+    return gettext(string)
+
+
+def ntranslate(singular, plural, num, context=None):
+    if context:
+        return npgettext(context, singular, plural, num)
+    return ngettext(singular, plural, num)
+
+
+def lazy_translate(string, context=None):
+    if context:
+        return lazy_pgettext(context, string)
+    return lazy_gettext(string)
+
+
 def format_currency(number, format=None):
     return babel_format_currency(number, get_currency(), format)
 
