@@ -193,11 +193,11 @@ class StripeSubscriptionModelMixin(StripeModelMixin):
         if self.stripe_subscription_id:
             self._update_stripe_subscription(False)
 
-    def subscribe_stripe_plan(self, plan=None, quantity=1, item_options=None, trial_end=None, **kwargs):
+    def subscribe_stripe_plan(self, plan=None, quantity=1, item_options=None, trial_end=None, force=False, **kwargs):
         state = get_extension_state('frasco_stripe')
         if not plan:
             plan = state.options['default_plan']
-        if self.stripe_subscription_id and self.plan_name == plan:
+        if self.stripe_subscription_id and self.plan_name == plan and self.plan_status != 'canceled' and not force:
             return
 
         item = dict(plan=plan, quantity=quantity)
