@@ -4,12 +4,6 @@ import datetime
 
 
 class JSONEncoder(json.JSONEncoder):
-    """A JSONEncoder which always activates the for_json feature
-    """
-    def __init__(self, *args, **kwargs):
-        kwargs["for_json"] = True
-        super(JSONEncoder, self).__init__(*args, **kwargs)
-
     def default(self, o):
         if isinstance(o, speaklater._LazyString):
             return o.value
