@@ -1,16 +1,16 @@
 from flask import request, flash, redirect, session, current_app, Blueprint
 from frasco.helpers import url_for
 from frasco.ext import get_extension_state
-from frasco.users.user import login_user, is_user_logged_in, current_user
+from frasco.users.user import login_user, is_user_logged_in, current_user, validate_user_email
+from frasco.users.model import UserEmailValidatedMixin
 from frasco.models import db
 from frasco.utils import populate_obj
 from frasco.tasks import get_current_job
 from frasco.redis.objects import JSONRedisHash
-from authlib.flask.client import OAuth
+from authlib.integrations.flask_client import OAuth
 from sqlalchemy.dialects import postgresql
 import datetime
 import uuid
-import hashlib
 
 
 class OAuth1RequestTokenCache(object):
@@ -65,7 +65,7 @@ class OAuthUserModelMixin(object):
     @classmethod
     def query_by_oauth_token(cls, provider, id_property, id_value):
         return cls.query.join(cls.__oauth_token_model__).filter(
-            cls.__oauth_token_model__.data[id_property].astext == unicode(id_value)).first()
+            cls.__oauth_token_model__.data[id_property].astext == str(id_value)).first()
 
     def get_oauth_token(self, provider):
         return self.oauth_tokens.filter(self.__oauth_token_model__.provider == provider).first()
@@ -154,35 +154,43 @@ def oauth_session_login(provider, token, redirect_url=None):
     return redirect(redirect_url)
 
 
-def oauth_login(provider, id_property, id_value, data, defaults, redirect_url=None):
+def oauth_login(provider, id_property, id_value, data, defaults, redirect_url=None, auto_associate_with_matching_email=False, validate_email=True):
     """Execute a login via oauth. If no user exists, oauth_signup() will be called
     """
     state = get_extension_state('frasco_users')
     user = state.Model.query_by_oauth_token(provider, id_property, id_value)
     if not redirect_url:
         redirect_url = request.args.get('next') or url_for(state.options["redirect_after_login"])
+
     if is_user_logged_in():
         if user and user != current_user:
             if state.options["oauth_user_already_exists_message"]:
                 flash(state.options["oauth_user_already_exists_message"].format(provider=provider), "error")
             return redirect(redirect_url)
         user = current_user
-        if provider not in user.auth_providers:
-            user.auth_providers.append(provider)
-    elif not user:
-        return oauth_signup(provider, data, defaults, redirect_url=redirect_url)
-    else:
-        login_user(user, provider=provider)
+    elif not user and defaults.get('email') and auto_associate_with_matching_email:
+        user = state.Model.query_by_email(defaults['email']).first()
+    
+    if not user:
+        return oauth_signup(provider, data, defaults, redirect_url=redirect_url, validate_email=validate_email)
+    
     user.save_oauth_token_data(provider, data)
+    if provider not in user.auth_providers:
+        user.auth_providers.append(provider)
+    if validate_email and hasattr(user, 'email_validated') and not user.email_validated and user.email == defaults.get('email'):
+        validate_user_email(user)
+    if not is_user_logged_in():
+        login_user(user, provider=provider)
     return redirect(redirect_url)
 
 
-def oauth_signup(provider, data, defaults, redirect_url=None):
+def oauth_signup(provider, data, defaults, redirect_url=None, validate_email=True):
     """Start the signup process after having logged in via oauth
     """
     session["oauth_signup"] = provider
     session["oauth_data"] = data
     session["oauth_user_defaults"] = defaults
+    session["oauth_validate_email"] = validate_email
     if not redirect_url:
         redirect_url = request.args.get("next")
     return redirect(url_for('users.oauth_signup', next=redirect_url))
@@ -192,3 +200,4 @@ def clear_oauth_signup_session():
     session.pop("oauth_signup", None)
     session.pop("oauth_data", None)
     session.pop("oauth_user_defaults", None)
+    session.pop("oauth_validate_email", None)
